import { useState, useEffect } from 'react';
import handleObjectCRUD from '../../../utils/handleObjectCRUD';
import { addCustomEventListener, removeCustomEventListener } from '../../../utils/customEventDispatcher.js';
import { DUMMY_OBJECT } from '../../../utils/constants';
import { DOT_SERVICE_EVENT, DOT_SERVICE_EVENT_TYPE_SHOW_ATTACHMENT_VIEWER, DOT_SERVICE_EVENT_TYPE_HIDE_ATTACHMENT_VIEWER } from '../../../service/helpers/constant';

const useDOTAttachmentViewerService = () => {
  const {
    setObjectValue: _showAttachment,
    clearObjectValue: _clearAttachment,
    getObject: _getAttachmentData
  } = handleObjectCRUD();
  const [attachment, setAttachment] = useState(DUMMY_OBJECT);

  const handleService = event => {
    const {
      type,
      payload
    } = event.detail;

    switch (type) {
      case DOT_SERVICE_EVENT_TYPE_SHOW_ATTACHMENT_VIEWER:
        _showAttachment(payload);

        setAttachment(_getAttachmentData());
        break;

      case DOT_SERVICE_EVENT_TYPE_HIDE_ATTACHMENT_VIEWER:
        _clearAttachment();

        setAttachment(_getAttachmentData());
        break;

      default:
        console.error('No such service found in DOT Attachment Viewer Service');
        break;
    }
  };

  useEffect(() => {
    // Add event listener
    addCustomEventListener({
      eventName: DOT_SERVICE_EVENT,
      callback: handleService
    });
    return () => {
      // Return a cleanup function to remove the event listener
      removeCustomEventListener({
        eventName: DOT_SERVICE_EVENT,
        callback: handleService
      });
    };
  }, []);
  return {
    attachment
  };
};

export default useDOTAttachmentViewerService;